#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const DnsPacket_1 = require("./DnsPacket");
const node_dgram_1 = __importDefault(require("node:dgram"));
const commander_1 = require("commander");
function resolveName(name) {
    return new Promise((resolve, reject) => {
        const dnsPacket = DnsPacket_1.DnsPacket.createQueryPacket(name);
        const server = node_dgram_1.default.createSocket('udp4');
        server.on('error', (err) => {
            server.close();
            reject(err);
        });
        server.on('message', (msg) => {
            const dnsResponse = DnsPacket_1.DnsPacket.fromBytes(msg);
            resolve(dnsResponse.getAnswer());
        });
        server.bind(41234);
        server.send(dnsPacket.toBuffer(), 53, '8.8.8.8', (err) => {
            if (err) {
                reject(err);
            }
        });
    });
}
commander_1.program
    .name('dns-stub-resolver')
    .description('CLI to resolve a domain name to a v4 IP address')
    .version('1.0.0')
    .argument('<domain_name>', 'The domain name to resolve to an IP address')
    .action((domainName) => {
    resolveName(domainName)
        .then((ip) => {
        console.log(ip);
        process.exit(0);
    })
        .catch((err) => {
        console.error(err.toString());
        process.exit(1);
    });
})
    .parse(process.argv);
